==> kubernetes-model-core-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/TCPSocketActionFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import com.fasterxml.jackson.databind.JsonSerializer;
import java.lang.String;
import com.fasterxml.jackson.databind.JsonDeserializer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.SerializerProvider;
import java.lang.Boolean;
import java.lang.Override;
import com.fasterxml.jackson.core.JsonParser;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Object;

public class TCPSocketActionFluentImpl<A extends TCPSocketActionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements TCPSocketActionFluent<A> {

    private String host;
    private IntOrStringBuilder port;

    public TCPSocketActionFluentImpl() {
    }

    public TCPSocketActionFluentImpl(TCPSocketAction instance) {
        this.withHost(instance.getHost()); 
        this.withPort(instance.getPort()); 
    }

    public String getHost() {
        return this.host;
    }

    public A withHost(String host) {
        this.host=host; return (A) this;
    }

    public Boolean hasHost() {
        return this.host != null;
    }

    public A withNewHost(StringBuilder arg1) {
        return (A)withHost(new String(arg1));
    }

    public A withNewHost(int[] arg1,int arg2,int arg3) {
        return (A)withHost(new String(arg1, arg2, arg3));
    }

    public A withNewHost(char[] arg1) {
        return (A)withHost(new String(arg1));
    }

    public A withNewHost(StringBuffer arg1) {
        return (A)withHost(new String(arg1));
    }

    public A withNewHost(byte[] arg1,int arg2) {
        return (A)withHost(new String(arg1, arg2));
    }

    public A withNewHost(byte[] arg1) {
        return (A)withHost(new String(arg1));
    }

    public A withNewHost(char[] arg1,int arg2,int arg3) {
        return (A)withHost(new String(arg1, arg2, arg3));
    }

    public A withNewHost(byte[] arg1,int arg2,int arg3) {
        return (A)withHost(new String(arg1, arg2, arg3));
    }

    public A withNewHost(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withHost(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewHost(String arg1) {
        return (A)withHost(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildPort instead.
 * @return The buildable object.
 */
@Deprecated public IntOrString getPort() {
        return this.port!=null?this.port.build():null;
    }

    public IntOrString buildPort() {
        return this.port!=null?this.port.build():null;
    }

    public A withPort(IntOrString port) {
        _visitables.get("port").remove(this.port);
        if (port!=null){ this.port= new IntOrStringBuilder(port); _visitables.get("port").add(this.port);} return (A) this;
    }

    public Boolean hasPort() {
        return this.port != null;
    }

    public A withNewPort(String strVal) {
        return (A)withPort(new IntOrString(strVal));
    }

    public A withNewPort(Integer intVal) {
        return (A)withPort(new IntOrString(intVal));
    }

    public TCPSocketActionFluent.PortNested<A> withNewPort() {
        return new PortNestedImpl();
    }

    public TCPSocketActionFluent.PortNested<A> withNewPortLike(IntOrString item) {
        return new PortNestedImpl(item);
    }

    public TCPSocketActionFluent.PortNested<A> editPort() {
        return withNewPortLike(getPort());
    }

    public TCPSocketActionFluent.PortNested<A> editOrNewPort() {
        return withNewPortLike(getPort() != null ? getPort(): new IntOrStringBuilder().build());
    }

    public TCPSocketActionFluent.PortNested<A> editOrNewPortLike(IntOrString item) {
        return withNewPortLike(getPort() != null ? getPort(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        TCPSocketActionFluentImpl that = (TCPSocketActionFluentImpl) o;
        if (host != null ? !host.equals(that.host) :that.host != null) return false;
        if (port != null ? !port.equals(that.port) :that.port != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(host,  port,  super.hashCode());
    }

    public class PortNestedImpl<N> extends IntOrStringFluentImpl<TCPSocketActionFluent.PortNested<N>> implements TCPSocketActionFluent.PortNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final IntOrStringBuilder builder;

            PortNestedImpl(IntOrString item) {
                this.builder = new IntOrStringBuilder(this, item);
                        
            }

            PortNestedImpl() {
                this.builder = new IntOrStringBuilder(this);
                        
            }

            public N and() {
                return (N) TCPSocketActionFluentImpl.this.withPort(builder.build());
            }

            public N endPort() {
                return and();
            }
    }


}

==> kubernetes-model-core-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/TCPSocketActionFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import com.fasterxml.jackson.databind.JsonSerializer;
import java.lang.String;
import com.fasterxml.jackson.databind.JsonDeserializer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.SerializerProvider;
import java.lang.Boolean;
import com.fasterxml.jackson.core.JsonProcessingException;
import java.lang.Override;
import com.fasterxml.jackson.core.JsonParser;
import java.io.IOException;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Object;

public class TCPSocketActionFluentImpl<A extends TCPSocketActionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements TCPSocketActionFluent<A> {

    private String host;
    private IntOrStringBuilder port;

    public TCPSocketActionFluentImpl() {
    }

    public TCPSocketActionFluentImpl(TCPSocketAction instance) {
        this.withHost(instance.getHost()); 
        this.withPort(instance.getPort()); 
    }

    public String getHost() {
        return this.host;
    }

    public A withHost(String host) {
        this.host=host; return (A) this;
    }

    public Boolean hasHost() {
        return this.host != null;
    }

    public A withNewHost(StringBuilder arg1) {
        return (A)withHost(new String(arg1));
    }

    public A withNewHost(int[] arg1,int arg2,int arg3) {
        return (A)withHost(new String(arg1, arg2, arg3));
    }

    public A withNewHost(char[] arg1) {
        return (A)withHost(new String(arg1));
    }

    public A withNewHost(StringBuffer arg1) {
        return (A)withHost(new String(arg1));
    }

    public A withNewHost(byte[] arg1,int arg2) {
        return (A)withHost(new String(arg1, arg2));
    }

    public A withNewHost(byte[] arg1) {
        return (A)withHost(new String(arg1));
    }

    public A withNewHost(char[] arg1,int arg2,int arg3) {
        return (A)withHost(new String(arg1, arg2, arg3));
    }

    public A withNewHost(byte[] arg1,int arg2,int arg3) {
        return (A)withHost(new String(arg1, arg2, arg3));
    }

    public A withNewHost(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withHost(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewHost(String arg1) {
        return (A)withHost(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildPort instead.
 * @return The buildable object.
 */
@Deprecated public IntOrString getPort() {
        return this.port!=null?this.port.build():null;
    }

    public IntOrString buildPort() {
        return this.port!=null?this.port.build():null;
    }

    public A withPort(IntOrString port) {
        _visitables.get("port").remove(this.port);
        if (port!=null){ this.port= new IntOrStringBuilder(port); _visitables.get("port").add(this.port);} return (A) this;
    }

    public Boolean hasPort() {
        return this.port != null;
    }

    public A withNewPort(String strVal) {
        return (A)withPort(new IntOrString(strVal));
    }

    public A withNewPort(Integer intVal) {
        return (A)withPort(new IntOrString(intVal));
    }

    public io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<A> withNewPort() {
        return new PortNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<A> withNewPortLike(IntOrString item) {
        return new PortNestedImpl(item);
    }

    public io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<A> editPort() {
        return withNewPortLike(getPort());
    }

    public io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<A> editOrNewPort() {
        return withNewPortLike(getPort() != null ? getPort(): new IntOrStringBuilder().build());
    }

    public io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<A> editOrNewPortLike(IntOrString item) {
        return withNewPortLike(getPort() != null ? getPort(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        TCPSocketActionFluentImpl that = (TCPSocketActionFluentImpl) o;
        if (host != null ? !host.equals(that.host) :that.host != null) return false;
        if (port != null ? !port.equals(that.port) :that.port != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(host,  port,  super.hashCode());
    }

    public class PortNestedImpl<N> extends IntOrStringFluentImpl<io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<N>> implements io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final IntOrStringBuilder builder;

            PortNestedImpl(IntOrString item) {
                this.builder = new IntOrStringBuilder(this, item);
                        
            }

            PortNestedImpl() {
                this.builder = new IntOrStringBuilder(this);
                        
            }

            public N and() {
                return (N) TCPSocketActionFluentImpl.this.withPort(builder.build());
            }

            public N endPort() {
                return and();
            }
    }


}
